pub fn decode_failure(output: &Value) -> Option<ToolFailure>Expand description
Decodes a completion output that is the failure sentinel, if it is one.
pub fn decode_failure(output: &Value) -> Option<ToolFailure>Decodes a completion output that is the failure sentinel, if it is one.